# AuraTrace Documentation

Welcome to the official documentation for [AuraTrace](https://github.com/Cosmos-Coder-Ray/AuraTrace.git) — the AI-powered data lineage and observability tool for Python. AuraTrace transparently traces data pipelines using pandas, Dask, and PyArrow, providing deep insights, quality checks, performance monitoring, and AI-assisted analysis.

## 📚 Documentation Index

### Getting Started
- [Installation Guide](installation.md)
- [Quick Start](quickstart.md)
- [Basic Usage](basic-usage.md)

### User Guides
- [CLI Reference](cli-reference.md)
- [API Reference](api-reference.md)
- [Configuration](configuration.md)
- [Quality Rules](quality-rules.md)

### Advanced Topics
- [Architecture](architecture.md)
- [Performance Tuning](performance-tuning.md)
- [AI Assistant](ai-assistant.md)
- [Custom Rules](custom-rules.md)

### Examples & Tutorials
- [Example Pipelines](examples/pipelines.md)
- [Data Quality Checks](examples/quality-checks.md)
- [Performance Analysis](examples/performance-analysis.md)
- [AI Analysis](examples/ai-analysis.md)

### Development
- [Contributing](contributing.md)
- [Development Setup](development.md)
- [Testing](testing.md)
- [Release Process](release.md)

## 🚀 Quick Navigation

**For New Users:**
1. [Installation Guide](installation.md)
2. [Quick Start](quickstart.md)
3. [Basic Usage](basic-usage.md)

**For Data Scientists:**
- [Example Pipelines](examples/pipelines.md)
- [Quality Rules](quality-rules.md)
- [AI Assistant](ai-assistant.md)

**For Developers:**
- [Architecture](architecture.md)
- [Development Setup](development.md)
- [Contributing](contributing.md)

## 🏗️ Documentation Structure

```
docs/
├── README.md                 # This file
├── installation.md           # Installation guide
├── quickstart.md             # Quick start tutorial
├── basic-usage.md            # Basic usage guide
├── cli-reference.md          # CLI documentation
├── api-reference.md          # API documentation
├── configuration.md          # Configuration guide
├── quality-rules.md          # Quality rules guide
├── architecture.md           # Architecture overview
├── performance-tuning.md     # Performance guide
├── ai-assistant.md           # AI assistant guide
├── custom-rules.md           # Custom rules guide
├── contributing.md           # Contributing guide
├── development.md            # Development setup
├── testing.md                # Testing guide
├── release.md                # Release process
└── examples/                 # Example tutorials
    ├── pipelines.md
    ├── quality-checks.md
    ├── performance-analysis.md
    └── ai-analysis.md
```

## 🔗 Project Links

- [GitHub Repository](https://github.com/Cosmos-Coder-Ray/AuraTrace.git)
- [PyPI Package](https://pypi.org/project/auratrace/)
- [Issue Tracker](https://github.com/Cosmos-Coder-Ray/AuraTrace.git/issues)
- [Discussions](https://github.com/Cosmos-Coder-Ray/AuraTrace.git/discussions)

## 📝 Contributing to Documentation

We welcome contributions! See [Contributing Guide](contributing.md) for how to:
- Report documentation issues
- Suggest improvements
- Submit documentation updates
- Help translate documentation

## 🆘 Getting Help

If you need help with AuraTrace:
1. **Check the documentation**
2. **Search existing issues**
3. **Ask in discussions**
4. **Open an issue**

## 📄 License

This documentation is licensed under the Apache License 2.0, same as the AuraTrace project. 